@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
+import functools
+import operator
+import sys
+from io import BytesIO
+
+import numpy as np
 import pytest
+from numpy.testing import assert_array_equal
 from pytest import approx
 
 import boost_histogram as bh
 
-import numpy as np
-from numpy.testing import assert_array_equal
-from io import BytesIO
-import sys
-import operator
-import functools
-
 try:
     import cPickle as pickle
 except ImportError:
@@ -43,6 +43,8 @@ def test_init():
 
     h = bh.Histogram(bh.axis.Integer(-1, 2))
     assert h.ndim == 1
+    with pytest.warns(FutureWarning):
+        assert h.rank == 1
     assert h.axes[0] == bh.axis.Integer(-1, 2)
     assert h.axes[0].extent == 5
     assert h.axes[0].size == 3
